/* Copyright 2006 Nicholas Bishop
 * 
 * This file is part of SharpConstruct.
 *
 * SharpConstruct is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * SharpConstruct is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SharpConstruct; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */

#ifndef PROGRESS_H
#define PROGRESS_H

#include <sigc++/sigc++.h>
#include <string>

namespace SharpConstruct
{
	class Stepable
	{
	public:
		virtual ~Stepable();

		virtual double Progress() const = 0;
		virtual const std::string Text() const;
		virtual bool Step() = 0;

		static const bool DONE = false;
		static const bool CONTINUE = true;
	};

	class Progress
	{
	public:
		static Progress& Null();

		double Amount() const;
		const std::string& Text() const;

		void Update( const double );
		void Update( const double, const std::string );

		sigc::signal< void, const Progress& >& ChangedSignal();
	private:
		sigc::signal< void, const Progress& > changed_signal_;

		double amount_;
		std::string text_;
	};
}

#endif
