/* Copyright 2006 Nicholas Bishop
 * 
 * This file is part of SharpConstruct.
 *
 * SharpConstruct is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * SharpConstruct is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SharpConstruct; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */

#ifndef TOOLS_HH
#define TOOLS_HH

#include "Curve.hh"
#include "DeformationBase.hh"
#include "DisplaceBrush.hh"
#include "GrabBrush.hh"
#include "PinchBrush.hh"
#include "SmoothBrush.hh"

namespace SharpConstruct
{
	class Tools
	{
	public:
		static Tools& Instance();

		Brush::BrushBase* Brush();

		void SetInitialBrushShape( Glib::RefPtr< Gdk::Pixbuf >, const Gtk::TreePath );

		void SetDisplaceBrush();
		void SetGrabBrush();
		void SetPinchBrush();
		void SetSmoothBrush();

		bool InDeformationMode() const;
		DeformationBase* Deformation();

		void DeactivateDeformation();
		template< typename T > void SetDeformation()
		{
			delete deformation_;
			deformation_ = new T;
		}

		bool BrushCurveEnabled() const;
		void SetBrushCurveEnabled( const bool );
		CurveEditor& BrushCurve();
	private:
		Tools();

		Brush::BrushBase* brush_;
		Brush::Displace displace_brush_;
		Brush::Grab grab_brush_;
		Brush::Pinch pinch_brush_;
		Brush::Smooth smooth_brush_;

		DeformationBase* deformation_;

		bool brush_curve_enabled_;
		CurveEditor brush_curve_;
	};
}

#endif
