/* Copyright 2006 Nicholas Bishop
 * 
 * This file is part of SharpConstruct.
 *
 * SharpConstruct is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * SharpConstruct is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SharpConstruct; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */

#include "Log.hh"
#include <string>

#ifdef WIN32
#include <shlobj.h>
#include <shlwapi.h>
#endif

using SharpConstruct::Log;

Log::~Log()
{}

Log& Log::Instance()
{
	static Log instance;
	return instance;
}

void Log::Add( const std::string& msg )
{
	file_ << "> " << msg << std::endl;
	file_.flush();
}

Log::Log()
: file_( path_().c_str(), std::ios::out )
{

}

std::string Log::path_() const
{
	std::string path;

#ifdef WIN32
	char pth[MAX_PATH];
	SHGetFolderPath( 0, CSIDL_APPDATA, 0, 0, pth );
        PathAppend(pth,"\\SharpConstruct\\");
	path=pth;
#else
	path = "/tmp/";
#endif

	path += "sharpconstruct.log";

	return path;
}
