/* Copyright 2005 Nicholas Bishop
 * 
 * This file is part of SharpConstruct.
 *
 * SharpConstruct is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * SharpConstruct is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SharpConstruct; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */

#include "Mesh.hh"
#include "SmoothBrush.hh"
#include <cmath>

using SharpConstruct::Brush::Smooth;
using SharpConstruct::Brush::EditData;

SharpConstruct::Brush::SupportedProperties Smooth::Properties() const
{
	return SupportedProperties( true, true, false, false, false, true,
				    false, true, false );
}

void Smooth::start_sculpt_( const EditData& e )
{
	Mesh& mesh( MeshHistory::Instance().GetCurrentMesh() );

	mesh.FindActiveVertices( active_data_, e );

	// Loop through each active point
	for( unsigned i = 0; i < active_data_.size(); ++i )
	{
		if( Direction() != OFF && mesh.VertexUsers()[ active_data_[ i ].Index() ].Total() > 2 )
		{
			Point3D average = mesh.VertexNeighborLocAverage( active_data_[ i ].Index() );

			const float strength( active_data_[ i ].Strength() * fabs( Strength() * 25 ) );
			mesh.VertexLocations()[ active_data_[ i ].Index() ] += ( average - mesh.VertexLocations()[ active_data_[ i ].Index() ] ) *
				strength * mesh.Mask( active_data_[ i ].Index() );
		}
		if( Colorize() )
		{
			Color average = mesh.VertexNeighborClrAverage( active_data_[ i ].Index() );
			SharpConstruct::Color& v = mesh.VertexColors()[ active_data_[ i ].Index() ];
			
			const float intensity( active_data_[ i ].Strength() * Intensity() );
			v += ( average - v ) * intensity * mesh.Mask( active_data_[ i ].Index() );
		}
	}
}
